@@ -33,6 +33,7 @@ dynupdate <- function (data, newdata = NULL, holdoutdata, method = c("ts",
         if (method == "block") {
             updata = data$y[(dim(as.matrix(newdata))[1] + 1):length(as.numeric(data$y))]
             datamatrix = matrix(c(updata, newdata), p, )
+            colnames(datamatrix) = colnames(data$y)
             dummy = forecast.ftsm(ftsm(fts(1:p, datamatrix), 
                 order = order, ngrid = ngrid, method = pcdmethod), 
                 h = 1, method = fmethod, level = level)
@@ -91,38 +92,54 @@ dynupdate <- function (data, newdata = NULL, holdoutdata, method = c("ts",
         }
     }
     else {
+        if(method!="pls" & method!="block")
+        {
+           stop("Interval forecasts can only be updated using the block or pls method.")
+        }
         p = nrow(data$y)
         p2 = (length(newdata) + 1):p
         if (method == "pls") {
-            output = plsPI(data, newdata, order, B, (100 - level)/100, 
-                lambda)
-            return(list(forecasts = fts(p2, as.matrix(output$forecasts), 
-                xname = data$xname, yname = data$yname), bootsamp = fts(p2, 
-                as.matrix(output$bootsamp), xname = data$xname, 
-                yname = data$yname), low = fts(p2, as.matrix(output$low), 
-                xname = data$xname, yname = data$yname), up = fts(p2, 
-                as.matrix(output$up), xname = data$xname, yname = data$yname)))
+            if(pimethod != "nonparametric")
+            {
+                warning("Interval forecast updates from the PLS method can only be obtained via nonparametric bootstrap.")
+            }
+            output = plsPI(data = data, newdata = newdata, order = order, B = B, 
+                           alpha = (100 - level)/100, lambda = lambda)
+            plsPI_mat_forecasts = as.matrix(output$forecasts)
+            colnames(plsPI_mat_forecasts) = 1
+            
+            plsPI_mat_bootsamp = as.matrix(output$bootsamp)
+            colnames(plsPI_mat_bootsamp) = 1:B
+            
+            plsPI_mat_low = as.matrix(output$low)
+            plsPI_mat_up  = as.matrix(output$up)
+            colnames(plsPI_mat_low) = colnames(plsPI_mat_up) = 1
+            return(list(forecasts = fts(p2, plsPI_mat_forecasts, xname = data$xname, yname = data$yname), 
+                bootsamp = fts(p2, plsPI_mat_bootsamp, xname = data$xname, yname = data$yname), 
+                low = fts(p2, plsPI_mat_low, xname = data$xname, yname = data$yname), 
+                up = fts(p2, plsPI_mat_up, xname = data$xname, yname = data$yname)))
         }
         if (method == "block") {
             updata = data$y[(dim(as.matrix(newdata))[1] + 1):length(as.numeric(data$y))]
             datamatrix = matrix(c(updata, newdata), p, )
+            colnames(datamatrix) = colnames(data$y)
             dummy = forecast.ftsm(ftsm(fts(1:p, datamatrix), 
                 order = order, ngrid = ngrid, method = pcdmethod), 
                 h = 1, method = fmethod, level = level, pimethod = pimethod, 
                 B = B)
             if (pimethod == "parametric") {
-                lb = fts(p2, as.matrix(dummy$lower$y[1:length(holdoutdata)]), 
-                  xname = data$xname, yname = data$yname)
-                ub = fts(p2, as.matrix(dummy$upper$y[1:length(holdoutdata)]), 
-                  xname = data$xname, yname = data$yname)
+                lb_mat = as.matrix(dummy$lower$y[1:length(holdoutdata)])
+                ub_mat = as.matrix(dummy$upper$y[1:length(holdoutdata)])
+                colnames(lb_mat) = colnames(ub_mat) = 1
+                lb = fts(p2, lb_mat, xname = data$xname, yname = data$yname)
+                ub = fts(p2, ub_mat, xname = data$xname, yname = data$yname)
                 return(list(low = lb, up = ub))
             }
             if (pimethod == "nonparametric") {
                 lb = dummy$lower
                 ub = dummy$upper
                 boot_samp = dummy$bootsamp[1:length(p2), , ]
-                return(list(boot_samp = boot_samp, low = lb, 
-                  up = ub))
+                return(list(boot_samp = boot_samp, low = lb, up = ub))
             }
         }
     }
