@@ -1,4 +1,4 @@
-`func.trimvar.mode` <- function(data, trim = 0.25)
+func.trimvar.mode <- function(data, trim = 0.25)
 {
   functions = t(data$y)
   lista = depth.mode(data, trim = trim)$ltrim; 
