@@ -1,4 +1,4 @@
-me = function(forecast, true)
+me <- function(forecast, true)
 {
    if (length(forecast) != length(true))
        stop("ME: the lengths of input vectors must be the same.")
